==> ecs-1.60.0-sources.jar: software/amazon/awscdk/services/ecs/ClusterAttributes.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The properties to import from the ECS cluster.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:32.980Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.ClusterAttributes")
@software.amazon.jsii.Jsii.Proxy(ClusterAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ClusterAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the cluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getClusterName();

    /**
     * The security groups associated with the container instances registered to the cluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> getSecurityGroups();

    /**
     * The VPC associated with the cluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.IVpc getVpc();

    /**
     * Autoscaling group added to the cluster if capacity is added.
     * <p>
     * Default: - No default autoscaling group
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.autoscaling.IAutoScalingGroup getAutoscalingGroup() {
        return null;
    }

    /**
     * The Amazon Resource Name (ARN) that identifies the cluster.
     * <p>
     * Default: Derived from clusterName
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getClusterArn() {
        return null;
    }

    /**
     * The AWS Cloud Map namespace to associate with the cluster.
     * <p>
     * Default: - No default namespace
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.servicediscovery.INamespace getDefaultCloudMapNamespace() {
        return null;
    }

    /**
     * Specifies whether the cluster has EC2 instance capacity.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getHasEc2Capacity() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ClusterAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ClusterAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ClusterAttributes> {
        private java.lang.String clusterName;
        private java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups;
        private software.amazon.awscdk.services.ec2.IVpc vpc;
        private software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoscalingGroup;
        private java.lang.String clusterArn;
        private software.amazon.awscdk.services.servicediscovery.INamespace defaultCloudMapNamespace;
        private java.lang.Boolean hasEc2Capacity;

        /**
         * Sets the value of {@link ClusterAttributes#getClusterName}
         * @param clusterName The name of the cluster. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clusterName(java.lang.String clusterName) {
            this.clusterName = clusterName;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getSecurityGroups}
         * @param securityGroups The security groups associated with the container instances registered to the cluster. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder securityGroups(java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups) {
            this.securityGroups = securityGroups;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getVpc}
         * @param vpc The VPC associated with the cluster. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpc(software.amazon.awscdk.services.ec2.IVpc vpc) {
            this.vpc = vpc;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getAutoscalingGroup}
         * @param autoscalingGroup Autoscaling group added to the cluster if capacity is added.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoscalingGroup(software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoscalingGroup) {
            this.autoscalingGroup = autoscalingGroup;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getClusterArn}
         * @param clusterArn The Amazon Resource Name (ARN) that identifies the cluster.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clusterArn(java.lang.String clusterArn) {
            this.clusterArn = clusterArn;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getDefaultCloudMapNamespace}
         * @param defaultCloudMapNamespace The AWS Cloud Map namespace to associate with the cluster.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultCloudMapNamespace(software.amazon.awscdk.services.servicediscovery.INamespace defaultCloudMapNamespace) {
            this.defaultCloudMapNamespace = defaultCloudMapNamespace;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getHasEc2Capacity}
         * @param hasEc2Capacity Specifies whether the cluster has EC2 instance capacity.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hasEc2Capacity(java.lang.Boolean hasEc2Capacity) {
            this.hasEc2Capacity = hasEc2Capacity;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ClusterAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ClusterAttributes build() {
            return new Jsii$Proxy(clusterName, securityGroups, vpc, autoscalingGroup, clusterArn, defaultCloudMapNamespace, hasEc2Capacity);
        }
    }

    /**
     * An implementation for {@link ClusterAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ClusterAttributes {
        private final java.lang.String clusterName;
        private final java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups;
        private final software.amazon.awscdk.services.ec2.IVpc vpc;
        private final software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoscalingGroup;
        private final java.lang.String clusterArn;
        private final software.amazon.awscdk.services.servicediscovery.INamespace defaultCloudMapNamespace;
        private final java.lang.Boolean hasEc2Capacity;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.clusterName = this.jsiiGet("clusterName", java.lang.String.class);
            this.securityGroups = this.jsiiGet("securityGroups", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.ISecurityGroup.class)));
            this.vpc = this.jsiiGet("vpc", software.amazon.awscdk.services.ec2.IVpc.class);
            this.autoscalingGroup = this.jsiiGet("autoscalingGroup", software.amazon.awscdk.services.autoscaling.IAutoScalingGroup.class);
            this.clusterArn = this.jsiiGet("clusterArn", java.lang.String.class);
            this.defaultCloudMapNamespace = this.jsiiGet("defaultCloudMapNamespace", software.amazon.awscdk.services.servicediscovery.INamespace.class);
            this.hasEc2Capacity = this.jsiiGet("hasEc2Capacity", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String clusterName, final java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups, final software.amazon.awscdk.services.ec2.IVpc vpc, final software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoscalingGroup, final java.lang.String clusterArn, final software.amazon.awscdk.services.servicediscovery.INamespace defaultCloudMapNamespace, final java.lang.Boolean hasEc2Capacity) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.clusterName = java.util.Objects.requireNonNull(clusterName, "clusterName is required");
            this.securityGroups = java.util.Objects.requireNonNull(securityGroups, "securityGroups is required");
            this.vpc = java.util.Objects.requireNonNull(vpc, "vpc is required");
            this.autoscalingGroup = autoscalingGroup;
            this.clusterArn = clusterArn;
            this.defaultCloudMapNamespace = defaultCloudMapNamespace;
            this.hasEc2Capacity = hasEc2Capacity;
        }

        @Override
        public java.lang.String getClusterName() {
            return this.clusterName;
        }

        @Override
        public java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> getSecurityGroups() {
            return this.securityGroups;
        }

        @Override
        public software.amazon.awscdk.services.ec2.IVpc getVpc() {
            return this.vpc;
        }

        @Override
        public software.amazon.awscdk.services.autoscaling.IAutoScalingGroup getAutoscalingGroup() {
            return this.autoscalingGroup;
        }

        @Override
        public java.lang.String getClusterArn() {
            return this.clusterArn;
        }

        @Override
        public software.amazon.awscdk.services.servicediscovery.INamespace getDefaultCloudMapNamespace() {
            return this.defaultCloudMapNamespace;
        }

        @Override
        public java.lang.Boolean getHasEc2Capacity() {
            return this.hasEc2Capacity;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("clusterName", om.valueToTree(this.getClusterName()));
            data.set("securityGroups", om.valueToTree(this.getSecurityGroups()));
            data.set("vpc", om.valueToTree(this.getVpc()));
            if (this.getAutoscalingGroup() != null) {
                data.set("autoscalingGroup", om.valueToTree(this.getAutoscalingGroup()));
            }
            if (this.getClusterArn() != null) {
                data.set("clusterArn", om.valueToTree(this.getClusterArn()));
            }
            if (this.getDefaultCloudMapNamespace() != null) {
                data.set("defaultCloudMapNamespace", om.valueToTree(this.getDefaultCloudMapNamespace()));
            }
            if (this.getHasEc2Capacity() != null) {
                data.set("hasEc2Capacity", om.valueToTree(this.getHasEc2Capacity()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.ClusterAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ClusterAttributes.Jsii$Proxy that = (ClusterAttributes.Jsii$Proxy) o;

            if (!clusterName.equals(that.clusterName)) return false;
            if (!securityGroups.equals(that.securityGroups)) return false;
            if (!vpc.equals(that.vpc)) return false;
            if (this.autoscalingGroup != null ? !this.autoscalingGroup.equals(that.autoscalingGroup) : that.autoscalingGroup != null) return false;
            if (this.clusterArn != null ? !this.clusterArn.equals(that.clusterArn) : that.clusterArn != null) return false;
            if (this.defaultCloudMapNamespace != null ? !this.defaultCloudMapNamespace.equals(that.defaultCloudMapNamespace) : that.defaultCloudMapNamespace != null) return false;
            return this.hasEc2Capacity != null ? this.hasEc2Capacity.equals(that.hasEc2Capacity) : that.hasEc2Capacity == null;
        }

        @Override
        public int hashCode() {
            int result = this.clusterName.hashCode();
            result = 31 * result + (this.securityGroups.hashCode());
            result = 31 * result + (this.vpc.hashCode());
            result = 31 * result + (this.autoscalingGroup != null ? this.autoscalingGroup.hashCode() : 0);
            result = 31 * result + (this.clusterArn != null ? this.clusterArn.hashCode() : 0);
            result = 31 * result + (this.defaultCloudMapNamespace != null ? this.defaultCloudMapNamespace.hashCode() : 0);
            result = 31 * result + (this.hasEc2Capacity != null ? this.hasEc2Capacity.hashCode() : 0);
            return result;
        }
    }
}

==> ecs-1.100.0-sources.jar: software/amazon/awscdk/services/ecs/ClusterAttributes.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The properties to import from the ECS cluster.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:41.772Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.ClusterAttributes")
@software.amazon.jsii.Jsii.Proxy(ClusterAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ClusterAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the cluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getClusterName();

    /**
     * The security groups associated with the container instances registered to the cluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> getSecurityGroups();

    /**
     * The VPC associated with the cluster.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.IVpc getVpc();

    /**
     * Autoscaling group added to the cluster if capacity is added.
     * <p>
     * Default: - No default autoscaling group
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.autoscaling.IAutoScalingGroup getAutoscalingGroup() {
        return null;
    }

    /**
     * The Amazon Resource Name (ARN) that identifies the cluster.
     * <p>
     * Default: Derived from clusterName
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getClusterArn() {
        return null;
    }

    /**
     * The AWS Cloud Map namespace to associate with the cluster.
     * <p>
     * Default: - No default namespace
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.servicediscovery.INamespace getDefaultCloudMapNamespace() {
        return null;
    }

    /**
     * Specifies whether the cluster has EC2 instance capacity.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getHasEc2Capacity() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ClusterAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ClusterAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ClusterAttributes> {
        private java.lang.String clusterName;
        private java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups;
        private software.amazon.awscdk.services.ec2.IVpc vpc;
        private software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoscalingGroup;
        private java.lang.String clusterArn;
        private software.amazon.awscdk.services.servicediscovery.INamespace defaultCloudMapNamespace;
        private java.lang.Boolean hasEc2Capacity;

        /**
         * Sets the value of {@link ClusterAttributes#getClusterName}
         * @param clusterName The name of the cluster. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clusterName(java.lang.String clusterName) {
            this.clusterName = clusterName;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getSecurityGroups}
         * @param securityGroups The security groups associated with the container instances registered to the cluster. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder securityGroups(java.util.List<? extends software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups) {
            this.securityGroups = (java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup>)securityGroups;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getVpc}
         * @param vpc The VPC associated with the cluster. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder vpc(software.amazon.awscdk.services.ec2.IVpc vpc) {
            this.vpc = vpc;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getAutoscalingGroup}
         * @param autoscalingGroup Autoscaling group added to the cluster if capacity is added.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoscalingGroup(software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoscalingGroup) {
            this.autoscalingGroup = autoscalingGroup;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getClusterArn}
         * @param clusterArn The Amazon Resource Name (ARN) that identifies the cluster.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clusterArn(java.lang.String clusterArn) {
            this.clusterArn = clusterArn;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getDefaultCloudMapNamespace}
         * @param defaultCloudMapNamespace The AWS Cloud Map namespace to associate with the cluster.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultCloudMapNamespace(software.amazon.awscdk.services.servicediscovery.INamespace defaultCloudMapNamespace) {
            this.defaultCloudMapNamespace = defaultCloudMapNamespace;
            return this;
        }

        /**
         * Sets the value of {@link ClusterAttributes#getHasEc2Capacity}
         * @param hasEc2Capacity Specifies whether the cluster has EC2 instance capacity.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder hasEc2Capacity(java.lang.Boolean hasEc2Capacity) {
            this.hasEc2Capacity = hasEc2Capacity;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ClusterAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ClusterAttributes build() {
            return new Jsii$Proxy(clusterName, securityGroups, vpc, autoscalingGroup, clusterArn, defaultCloudMapNamespace, hasEc2Capacity);
        }
    }

    /**
     * An implementation for {@link ClusterAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ClusterAttributes {
        private final java.lang.String clusterName;
        private final java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups;
        private final software.amazon.awscdk.services.ec2.IVpc vpc;
        private final software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoscalingGroup;
        private final java.lang.String clusterArn;
        private final software.amazon.awscdk.services.servicediscovery.INamespace defaultCloudMapNamespace;
        private final java.lang.Boolean hasEc2Capacity;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.clusterName = software.amazon.jsii.Kernel.get(this, "clusterName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.securityGroups = software.amazon.jsii.Kernel.get(this, "securityGroups", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.ISecurityGroup.class)));
            this.vpc = software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
            this.autoscalingGroup = software.amazon.jsii.Kernel.get(this, "autoscalingGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.autoscaling.IAutoScalingGroup.class));
            this.clusterArn = software.amazon.jsii.Kernel.get(this, "clusterArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.defaultCloudMapNamespace = software.amazon.jsii.Kernel.get(this, "defaultCloudMapNamespace", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.servicediscovery.INamespace.class));
            this.hasEc2Capacity = software.amazon.jsii.Kernel.get(this, "hasEc2Capacity", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.String clusterName, final java.util.List<? extends software.amazon.awscdk.services.ec2.ISecurityGroup> securityGroups, final software.amazon.awscdk.services.ec2.IVpc vpc, final software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoscalingGroup, final java.lang.String clusterArn, final software.amazon.awscdk.services.servicediscovery.INamespace defaultCloudMapNamespace, final java.lang.Boolean hasEc2Capacity) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.clusterName = java.util.Objects.requireNonNull(clusterName, "clusterName is required");
            this.securityGroups = (java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup>)java.util.Objects.requireNonNull(securityGroups, "securityGroups is required");
            this.vpc = java.util.Objects.requireNonNull(vpc, "vpc is required");
            this.autoscalingGroup = autoscalingGroup;
            this.clusterArn = clusterArn;
            this.defaultCloudMapNamespace = defaultCloudMapNamespace;
            this.hasEc2Capacity = hasEc2Capacity;
        }

        @Override
        public final java.lang.String getClusterName() {
            return this.clusterName;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.ec2.ISecurityGroup> getSecurityGroups() {
            return this.securityGroups;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.IVpc getVpc() {
            return this.vpc;
        }

        @Override
        public final software.amazon.awscdk.services.autoscaling.IAutoScalingGroup getAutoscalingGroup() {
            return this.autoscalingGroup;
        }

        @Override
        public final java.lang.String getClusterArn() {
            return this.clusterArn;
        }

        @Override
        public final software.amazon.awscdk.services.servicediscovery.INamespace getDefaultCloudMapNamespace() {
            return this.defaultCloudMapNamespace;
        }

        @Override
        public final java.lang.Boolean getHasEc2Capacity() {
            return this.hasEc2Capacity;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("clusterName", om.valueToTree(this.getClusterName()));
            data.set("securityGroups", om.valueToTree(this.getSecurityGroups()));
            data.set("vpc", om.valueToTree(this.getVpc()));
            if (this.getAutoscalingGroup() != null) {
                data.set("autoscalingGroup", om.valueToTree(this.getAutoscalingGroup()));
            }
            if (this.getClusterArn() != null) {
                data.set("clusterArn", om.valueToTree(this.getClusterArn()));
            }
            if (this.getDefaultCloudMapNamespace() != null) {
                data.set("defaultCloudMapNamespace", om.valueToTree(this.getDefaultCloudMapNamespace()));
            }
            if (this.getHasEc2Capacity() != null) {
                data.set("hasEc2Capacity", om.valueToTree(this.getHasEc2Capacity()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.ClusterAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ClusterAttributes.Jsii$Proxy that = (ClusterAttributes.Jsii$Proxy) o;

            if (!clusterName.equals(that.clusterName)) return false;
            if (!securityGroups.equals(that.securityGroups)) return false;
            if (!vpc.equals(that.vpc)) return false;
            if (this.autoscalingGroup != null ? !this.autoscalingGroup.equals(that.autoscalingGroup) : that.autoscalingGroup != null) return false;
            if (this.clusterArn != null ? !this.clusterArn.equals(that.clusterArn) : that.clusterArn != null) return false;
            if (this.defaultCloudMapNamespace != null ? !this.defaultCloudMapNamespace.equals(that.defaultCloudMapNamespace) : that.defaultCloudMapNamespace != null) return false;
            return this.hasEc2Capacity != null ? this.hasEc2Capacity.equals(that.hasEc2Capacity) : that.hasEc2Capacity == null;
        }

        @Override
        public final int hashCode() {
            int result = this.clusterName.hashCode();
            result = 31 * result + (this.securityGroups.hashCode());
            result = 31 * result + (this.vpc.hashCode());
            result = 31 * result + (this.autoscalingGroup != null ? this.autoscalingGroup.hashCode() : 0);
            result = 31 * result + (this.clusterArn != null ? this.clusterArn.hashCode() : 0);
            result = 31 * result + (this.defaultCloudMapNamespace != null ? this.defaultCloudMapNamespace.hashCode() : 0);
            result = 31 * result + (this.hasEc2Capacity != null ? this.hasEc2Capacity.hashCode() : 0);
            return result;
        }
    }
}
